import { Card, CardBody, CardTitle, Grid, GridItem } from "@patternfly/react-core";
import React from "react";
import cockpit from "cockpit";
import { DOWNCLOCK_CPU_ID } from "../revpi-config/RevPiConfigService.js";
import { RevPiHelpText } from "../common.components.jsx";

const _ = cockpit.gettext;

export function SystemConfigurationCard (props) {
    const cardTitle = _("System Configuration");
    const {
        BoundSwitch,
        BoundToggle,
        BoundMultiToggle,
        BoundRevPiDropdown
    } = props.featureControlFactory;

    return (
        <Card isFullHeight name='system-configuration'>
            <CardTitle>
                {cardTitle}
                <RevPiHelpText title={cardTitle}>
                    {_("Configure your RevPi system settings here! Adjust CPU limits, manage network services, synchronize time, set up SSH, and select log storage locations.")}
                </RevPiHelpText>
            </CardTitle>
            <CardBody>
                <Grid hasGutter>
                    <GridItem span={12}>
                        <BoundMultiToggle id={DOWNCLOCK_CPU_ID} />
                    </GridItem>
                    <GridItem span={12}>
                        <BoundRevPiDropdown id={DOWNCLOCK_CPU_ID} />
                    </GridItem>
                    <GridItem span={12}>
                        <BoundSwitch id='avahi' />
                    </GridItem>
                    <GridItem span={12}>
                        <BoundSwitch id='systemd-timesyncd' />
                    </GridItem>
                    <GridItem span={12}>
                        <BoundSwitch id='dphys-swapfile' />
                    </GridItem>
                    <GridItem span={12}>
                        <BoundToggle id='var-log.mount' />
                    </GridItem>
                    <GridItem span={12}>
                        <BoundSwitch id='gui' />
                    </GridItem>
                    <GridItem span={12}>
                        <BoundSwitch id='ssh' />
                    </GridItem>
                </Grid>
            </CardBody>
        </Card>
    );
}
