import cockpit from "cockpit";

const _ = cockpit.gettext;

export function getConfigData () {
    return [
        {
            id: "downclock-cpu",
            title: _("Max CPU clock rate"),
            type: "config",
            responseCount: 2,
            options: [
                300,
                400,
                500,
                600,
                700,
                800,
                900,
                1000,
                1100,
                "MAX"
            ],
            // TODO: ALPHA: Remove either this or options above after final UI decision (REF: CPU_FREQ)
            options2: [
                300,
                // NOTE: 700 MHz is clock rate of the CM1 and must be available as distinct option
                700,
                1000,
                "MAX"
            ],
            unit: "MHz"
        },
        {
            id: "systemd-timesyncd",
            title: _("Time synchronization daemon"),
            type: "config"
        },
        {
            id: "ssh",
            title: _("SSH daemon to enable remote login"),
            type: "config"
        },
        {
            id: "gui",
            title: _("Boot to GUI"),
            type: "config",
            rebootRequired: true
        },
        {
            id: "dphys-swapfile",
            title: _("Swap"),
            type: "config"
        },
        {
            id: "var-log.mount",
            title: _("Store logs on"),
            type: "config",
            rebootRequired: true,
            options: {
                enabled: {
                    title: _("tmpfs-backed directory")
                },
                disabled: {
                    title: _("the eMMC")
                }
            }

        },
        {
            id: "bluetooth",
            title: _("Bluetooth"),
            type: "config",
            rebootRequired: true
        },
        {
            id: "ieee80211",
            title: _("WLAN"),
            type: "config",
            rebootRequired: true
        },
        {
            id: "external-antenna",
            title: _("Select antenna to use"),
            type: "config",
            rebootRequired: true,
            options: {
                enabled: {
                    title: "External Antenna via SMA"
                },
                disabled: {
                    title: "Internal Antenna"
                }
            }
        },

        {
            id: "pimodbus-master",
            title: _("Modbus Master"),
            type: "service"
        },
        {
            id: "pimodbus-slave",
            title: _("Modbus Slave"),
            type: "service"
        },
        {
            id: "nodered",
            title: _("Node-RED"),
            type: "service"
        },
        {
            id: "noderedrevpinodes-server",
            title: _("Node-RED RevPi Nodes Server"),
            type: "service"
        },
        {
            id: "revpipyload",
            title: _("RevPiPyLoad"),
            type: "service"
        },
        {
            id: "avahi",
            title: _("Avahi (ZeroConf)"),
            type: "service"
        },
        {
            id: "revpi-con-can",
            title: _("RevPi Con Can"),
            type: "config"
        },
        {
            id: "teamviewer-revpi",
            title: _("TeamViewer"),
            type: "config"
        },

        {
            id: "logi-rts",
            title: _("Logi RTS"),
            type: "config"
        }
    ];
}
